@@ -99,7 +99,7 @@ def parse_subhandler(context):
 								for kwarg in cw.keywords:
 									args[kwarg.arg] = kwarg.value.s if type(kwarg.value.s)==PORTABLE_STRING else PORTABLE_STRING(kwarg.value.s,encoding)
 								update_transdict(args['context'],args['source'],fname,cw.lineno,args['comment'])
-								print(args['context'],args['source'],fname,cw.lineno,args['comment'])
+								#print(args['context'],args['source'],fname,cw.lineno,args['comment'])
 								transcnt += 1
 								#for a in ast.walk(cw):
 									#if isinstance(a,
@@ -174,39 +174,43 @@ def parse_js(jsfpath):
 	f.close()
 	
 	transcnt = 0
-	tree = parser.parse(jsdata)
-	for node in nodevisitor.visit(tree):
-		pnames = ['source','context','comment']
-		if isinstance(node,jsast.FunctionCall):
-			ival = getattr(node.identifier,'value','')
-			if ival in [u'pysite_tr',u'pysite_tr_common',u'pysite_translate']:
-				args = []
-				for arg in node.children()[1:]:
-					args += [parse_string_arg(arg)]
-				if len(args)==0:
-					print("No arguments - skipping")
-				comment = u''
-				context = def_context
-				if node.identifier.value=='pysite_tr':
-					source = args[0]
-					if len(args)>1:
-						comment = args[1]
-				elif node.identifier.value=='pysite_tr_common':
-					context = u'js_common'
-					source = args[0]
-					if len(args)>1:
-						comment = args[1]
-				elif node.identifier.value=='pysite_translate':
-					source = args[0]
-					if len(args)==3:
-						context = args[1]
-						comment = args[2]
-					elif len(args)==2:
-						context = args[1]
-					if context.find(u'js_')!=0:
-						context = u'js_%s' % context
-				update_transdict(context,source,jsfpath,1,comment)
-				transcnt += 1
+	try:
+		tree = parser.parse(jsdata)
+		for node in nodevisitor.visit(tree):
+			pnames = ['source','context','comment']
+			if isinstance(node,jsast.FunctionCall):
+				ival = getattr(node.identifier,'value','')
+				if ival in [u'pysite_tr',u'pysite_tr_common',u'pysite_translate']:
+					args = []
+					for arg in node.children()[1:]:
+						args += [parse_string_arg(arg)]
+					if len(args)==0:
+						print("No arguments - skipping")
+					comment = u''
+					context = def_context
+					if node.identifier.value=='pysite_tr':
+						source = args[0]
+						if len(args)>1:
+							comment = args[1]
+					elif node.identifier.value=='pysite_tr_common':
+						context = u'js_common'
+						source = args[0]
+						if len(args)>1:
+							comment = args[1]
+					elif node.identifier.value=='pysite_translate':
+						source = args[0]
+						if len(args)==3:
+							context = args[1]
+							comment = args[2]
+						elif len(args)==2:
+							context = args[1]
+						if context.find(u'js_')!=0:
+							context = u'js_%s' % context
+					update_transdict(context,source,jsfpath,1,comment)
+					transcnt += 1
+	except Exception as e:
+		sys.stdout.write(u"Failed to parse: %s\n" % str(e.__class__))
+		return
 	print(u'Found %d translations' % transcnt)
 
 def parse_ts(ts_fname):
