@@ -226,7 +226,7 @@ class PySiteApplication(object):
 			subhandler = None
 			subhandler_py = join(self.basedir,'subhandlers','%s.py' % template)
 			if exists(subhandler_py):
-				subhandler = imp.load_source('subhandlers.%s' % template, subhandler_py)
+				subhandler = imp.load_source(template, subhandler_py)
 			
 			response_headers = []
 
@@ -273,9 +273,16 @@ class PySiteApplication(object):
 					raise e
 			
 			subhandler_redirect = getattr(subhandler,'redirect',None)
-			if subhandler_redirect:
+			instance_redirect = None
+			if shandler_instance:
+				instance_redirect = getattr(shandler_instance,'redirect',None)
+				
+			if subhandler_redirect or instance_redirect:
 				cookies = []
-				location = subhandler_redirect(template_info,cookies,environ)
+				if subhandler_redirect:
+					location = subhandler_redirect(template_info,cookies,environ)
+				elif instance_redirect:
+					location = shandler_instance.redirect()
 				if location:
 					output = redirect(location,cookies,start_response)
 					raise StopIteration
@@ -296,9 +303,9 @@ class PySiteApplication(object):
 			status = '501 Internal Server Error'
 			response_headers = []
 		
-		response_headers += [
-			('Content-type', 'text/html; charset=utf-8'),
-			('Content-Length', str(len(output)))]
+		if 'content-type' not in map(lambda x: x[0].lower(),response_headers):
+			response_headers += [('Content-type', 'text/html; charset=utf-8')]
+		response_headers += [('Content-Length', str(len(output)))]
 		
 		start_response(status, response_headers)
 		yield output
